%define anolis_release 1

%undefine _package_note_flags

%ifnarch %{ocaml_native_compiler}
%global debug_package %{nil}
%endif

# The topkg-care part has dependencies that themselves depend on the main
# package.  We do not build the care part for now.
%bcond_with care

Name:           ocaml-topkg
Version:        1.0.7
Release:        %{anolis_release}%{?dist}
Summary:        The transitory OCaml software packager

License:        ISC
URL:            https://erratique.ch/software/topkg/
Source0:        https://github.com/dbuenzli/topkg/archive/v%{version}/topkg-%{version}.tar.gz

BuildRequires:  ocaml >= 4.05.0
BuildRequires:  ocaml-findlib >= 1.6.1
BuildRequires:  ocaml-ocamlbuild
BuildRequires:  python3

%if %{with care}
BuildRequires:  ocaml-bos-devel >= 0.1.5
BuildRequires:  ocaml-cmdliner-devel >= 1.0.0
BuildRequires:  ocaml-fmt-devel
BuildRequires:  ocaml-logs-devel
BuildRequires:  ocaml-webbrowser-devel
BuildRequires:  ocaml-opam-format-devel >= 2.0.0
%endif

Obsoletes:      ocaml-topkg-doc < 1.0.5-4

%global _desc %{expand:
Topkg is a packager for distributing OCaml software.  It provides an
API to describe the files a package installs in a given build
configuration and to specify information about the package's
distribution, creation and publication procedures.}

%description %_desc

%package        devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and signature files for
developing applications that use %{name}.

%if %{with care}
%package        care
Summary:        Command line tool for the transitory OCaml software packager
Requires:       %{name} = %{version}-%{release}
Requires:       ocaml-ocamlbuild

%description    care %_desc

This package provides a command line tool which helps with various
aspects of a package's life cycle: creating and linting a distribution,
releasing it on the web, publishing its documentation, adding it to the
OCaml opam repository, etc.

%package        care-devel
Summary:        Development files for %{name}-care
Requires:       %{name}-care = %{version}-%{release}
Requires:       ocaml-bos-devel
Requires:       ocaml-cmdliner-devel
Requires:       ocaml-fmt-devel
Requires:       ocaml-logs-devel
Requires:       ocaml-opam-format-devel
Requires:       ocaml-webbrowser-devel

%description    care-devel
The %{name}-care-devel package contains libraries and signature files
for developing applications that use %{name}-care.
%endif

%package        doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{EVR}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -n topkg-%{version} -p1

# This package can replace "watermarks" in software that it builds.  However,
# we are building from scratch, rather than using topkg to build itself, so we
# have to do the job manually.
for fil in $(find . -type f); do
  sed -e 's,%%%%NAME%%%%,topkg,' \
      -e 's,%%%%PKG_DOC%%%%,%{url}doc/,' \
      -e 's,%%%%PKG_HOMEPAGE%%%%,%{url},' \
      -e 's,%%%%VERSION%%%%,v%{version},' \
      -e 's,%%%%VERSION_NUM%%%%,%{version},' \
      -i.orig $fil
  touch -r $fil.orig $fil
  rm $fil.orig
done

%build
# Build the library and the tests
ocaml pkg/pkg.ml build --pkg-name topkg --tests true

%if %{with care}
# Build topkg-care
ocaml pkg/pkg.ml build --pkg-name topkg-care --tests true
%endif

%install
mkdir -p %{buildroot}%{ocamldir}/topkg
cp -p _build/topkg.opam %{buildroot}%{ocamldir}/topkg/opam
cp -p _build/pkg/META %{buildroot}%{ocamldir}/topkg/META
%ifarch %{ocaml_native_compiler}
cp -p _build/src/topkg.{a,cma,cmi,cmti,cmxa,cmxs,mli} _build/src/*.cmx \
  %{buildroot}%{ocamldir}/topkg
%else
cp -p _build/src/topkg.{cma,cmi,cmti,mli} %{buildroot}%{ocamldir}/topkg
%endif

%if %{with care}
mkdir -p %{buildroot}%{_bindir}
%ifarch %{ocaml_native_compiler}
cp -p _build/src-bin/topkg_bin.native %{buildroot}%{_bindir}/topkg
cp -p _build/src-bin/toy_github_delegate.native \
   %{buildroot}%{_bindir}/toy_github_delegate
%else
cp -p _build/src-bin/topkg_bin.byte %{buildroot}%{_bindir}/topkg
cp -p _build/src-bin/toy_github_delegate.byte \
   %{buildroot}%{_bindir}/toy_github_delegate
%endif

# Install the CARE library
mkdir -p %{buildroot}%{ocamldir}/topkg-care
cp -p _build/topkg-care.opam %{buildroot}%{ocamldir}/topkg-care/opam
%ifarch %{ocaml_native_compiler}
cp -a _build/src-care/*.{a,cma,cmi,cmt,cmti,cmx,cmxa,cmxs,mli} \
  %{buildroot}%{ocamldir}/topkg-care
%else
cp -a _build/src-care/*.{cma,cmi,cmt,cmti,mli} \
  %{buildroot}%{ocamldir}/topkg-care
%endif
%endif

%ocaml_files -s

%if %{with care}
%check
ocaml pkg/pkg.ml test
%endif

%generate_compatibility_deps

%files -f .ofiles-topkg
%license LICENSE.md

%files devel -f .ofiles-topkg-devel

%if %{with care}
%files care -f .ofiles-care

%files care-devel -f .ofiles-care-devel
%endif

%files doc
%doc CHANGES.md README.md

%changelog
* Thu Mar 23 2023 Yuanhong Peng <yummypeng@linux.alibaba.com> - 1.0.7-1
- Init from upstream
